@@ -1,5 +1,5 @@
 package Crypt::Passphrase;
-$Crypt::Passphrase::VERSION = '0.003';
+$Crypt::Passphrase::VERSION = '0.004';
 use strict;
 use warnings;
 
@@ -112,7 +112,7 @@ Crypt::Passphrase - A module for managing passwords in a cryptographically agile
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -149,7 +149,7 @@ A C<Crypt::Passphrase> object has a single encoder. This can be passed in three
 
 =item * A simple string
 
-The name of the encoder class. If the value starts with a C<+>, the C<+> will be removed and the remainder will be taken as a fully-qualified package name. Otherwise, C<Crypt::Passphrase::> will be prepended to he value.
+The name of the encoder class. If the value starts with a C<+>, the C<+> will be removed and the remainder will be taken as a fully-qualified package name. Otherwise, C<Crypt::Passphrase::> will be prepended to the value.
 
 The class will be loaded, and constructed without arguments.
 
@@ -193,9 +193,11 @@ Calling this only ever makes sense after a password has been verified.
 
 While encoders generally allow for a default configuration, I would strongly encourage anyone to research what settings work for your application. It is generally a trade-off between usability/resources and security.
 
+The configuration for C<Crypt::Passphrase> should generally be part of your application configuration file, and not be hardcoded if that can be avoided.
+
 =head2 Unicode
 
-C<Crypt::Password> considers passwords to be text, and as such you should ensure any password input is decoded if it contains any non-ascii characters. C<Crypt::Password> will take care of both normalizing and encoding such input.
+C<Crypt::Passphrase> considers passwords to be text, and as such you should ensure any password input is decoded if it contains any non-ascii characters. C<Crypt::Passphrase> will take care of both normalizing and encoding such input.
 
 =head2 DOS attacks
 
@@ -215,6 +217,8 @@ In some situations, it may be appropriate to have different password settings fo
 
 =item * L<Crypt::Passphrase::Scrypt|Crypt::Passphrase::Scrypt>
 
+=item * L<Crypt::Passphrase::PBKDF2|Crypt::Passphrase::PBKDF2>
+
 =back
 
 =head1 AUTHOR
